==================
Kotti CMS Analysis
==================

:Authors: Daniel Nouri, Mike Orr

Structural analysis of Kotti.

This chapter and all subchapters are unfinished.

.. toctree::

   overview
   database
